# install .NET Framework 3.5 if not already installed - SQL Tools requires it
if (-not (test-path "hklm:\SOFTWARE\Microsoft\NET Framework Setup\NDP\v3.5")) {
  Write-Host "Adding .NET Framework 3.5 dependency"

  $osVersion = (Get-WmiObject -class Win32_OperatingSystem).Version
  if($osVersion -ge 6.2) {
    Add-WindowsFeature NET-Framework-Features
    Add-WindowsFeature NET-Framework-Core
  } else {
    Add-WindowsCapability -Online -Name NetFx3~~~~          
  }
}

Write-Host "Adding SQL Server Express 2014 SP1 with Tools"

$arguments = @{}

# default values
$instanceId                 = "SQLEXPRESS"
$instanceName               = "SQLEXPRESS"
$sqlSecurityMode            = [string]::Empty
$saPwd                      = [string]::Empty
$sqlSysAdminAccounts        = [string]::Empty
$sqlServiceAccount          = [string]::Empty
$sqlServiceAccountPwd       = [string]::Empty
$sqlCollation               = [string]::Empty
$sqlBrowserServiceStartup   = 'Manual'
$sqlServiceStartup          = 'Automatic'

$packageParameters = $env:chocolateyPackageParameters      
if (-not [string]::IsNullOrEmpty($packageParameters )) {
    $match_pattern = "\/(?<option>([a-zA-Z]+))(:(?<value>([`"'])?([a-zA-Z0-9- _\\:\.\!]+)([`"'])?)+)?"
    $option_name = 'option'
    $value_name = 'value'

    if ($packageParameters -match $match_pattern ) {
        $results = $packageParameters | Select-String $match_pattern -AllMatches
        $results.matches | % {
            $arguments.Add(
                $_.Groups[$option_name].Value.Trim(), 
                $_.Groups[$value_name].Value.Trim())
        }    
    } 
    else {
        Throw "Package Parameters were found but were invalid (REGEX Failure)"
    }
}

if ($arguments.ContainsKey("INSTANCEID")) {
    $instanceId = $arguments["INSTANCEID"]
}

if ($arguments.ContainsKey("INSTANCENAME")) {
    $instanceName = $arguments["INSTANCENAME"]
}

if ($arguments.ContainsKey("SECURITYMODE")) {
    $sqlSecurityMode = $arguments["SECURITYMODE"]
}
      
if ($arguments.ContainsKey("SAPWD")) {
    $saPwd = $arguments["SAPWD"]
}

if ($arguments.ContainsKey("SQLSYSADMINACCOUNTS")) {
    $sqlSysAdminAccounts = $arguments["SQLSYSADMINACCOUNTS"]
}

if ($arguments.ContainsKey("SQLSVCACCOUNT")) {
    $sqlServiceAccount = $arguments["SQLSVCACCOUNT"]
}

if ($arguments.ContainsKey("SQLSVCPASSWORD")) {
    $sqlServiceAccountPwd = $arguments["SQLSVCPASSWORD"]
}
    
if ($arguments.ContainsKey("SQLCOLLATION")) {
    $sqlCollation = $arguments["SQLCOLLATION"]
}

if ($arguments.ContainsKey("BROWSERSVCSTARTUPTYPE")) {
    $sqlBrowserServiceStartup = $arguments["BROWSERSVCSTARTUPTYPE"]
}

if ($arguments.ContainsKey("SQLSVCSTARTUPTYPE")) {
    $sqlServiceStartup = $arguments["SQLSVCSTARTUPTYPE"]
}
        
$silentArgs = " /Q /IAcceptSQLServerLicenseTerms /ACTION=install /UPDATEENABLED /TCPENABLED=1 /NPENABLED=1 "
$silentArgs = $silentArgs + " /INSTANCEID=" + $instanceId + " /INSTANCENAME=" + $instanceName 
$silentArgs = $silentArgs + " /SQLSVCSTARTUPTYPE=" + $sqlServiceStartup + " /BROWSERSVCSTARTUPTYPE=" + $sqlBrowserServiceStartup

if (-not [string]::IsNullOrEmpty($sqlSecurityMode)) {
    if ([string]::IsNullOrEmpty($saPwd)) {
        Throw "/SAPWD is required when SQL security mode is used"
    }

    $silentArgs  = $silentArgs  + " /SECURITYMODE=" + $sqlSecurityMode + " /SAPWD=" + $saPwd
}

if (-not [string]::IsNullOrEmpty($sqlSysAdminAccounts)) {
    $silentArgs  = $silentArgs  + " /SQLSYSADMINACCOUNTS=" + $sqlSysAdminAccounts
}

if (-not [string]::IsNullOrEmpty($sqlServiceAccount)) {
    $silentArgs  = $silentArgs  + " /SQLSVCACCOUNT=" + $sqlServiceAccount
}

if (-not [string]::IsNullOrEmpty($sqlServiceAccountPwd)) {
    $silentArgs  = $silentArgs  + " /SQLSVCPASSWORD=" + $sqlServiceAccountPwd
}

if (-not [string]::IsNullOrEmpty($sqlCollation)) {
    $silentArgs  = $silentArgs  + " /SQLCOLLATION=" + $sqlCollation
}

$packageName = "MsSqlServer2014ExpressSp1WT"
$fileType = "exe"
$url32 = "https://download.microsoft.com/download/1/5/6/156992E6-F7C7-4E55-833D-249BD2348138/ENU/x86/SQLEXPRWT_x86_ENU.exe"
$url64 = "https://download.microsoft.com/download/1/5/6/156992E6-F7C7-4E55-833D-249BD2348138/ENU/x64/SQLEXPRWT_x64_ENU.exe"

Install-ChocolateyPackage $packageName $fileType $silentArgs $url32 $url64
